[Asterisk-code-review] spelling: resync (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:16:19 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/17166 )


Change subject: spelling: resync
......................................................................

spelling: resync

Change-Id: Iaf8f32b154246b0a5c4630481471bd8421c77ff7
---
M include/asterisk/abstract_jb.h
M main/fixedjitterbuf.c
M tests/test_jitterbuf.c
3 files changed, 12 insertions(+), 12 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/66/17166/1

diff --git a/include/asterisk/abstract_jb.h b/include/asterisk/abstract_jb.h
index eab571b..7ceb9f5 100644
--- a/include/asterisk/abstract_jb.h
+++ b/include/asterisk/abstract_jb.h
@@ -107,7 +107,7 @@
 typedef long (*jb_next_impl)(void *jb);
 /*! \brief Remove first frame */
 typedef int (*jb_remove_impl)(void *jb, struct ast_frame **fout);
-/*! \brief Force resynch */
+/*! \brief Force resync */
 typedef void (*jb_force_resynch_impl)(void *jb);
 /*! \brief Empty and reset jb */
 typedef void (*jb_empty_and_reset_impl)(void *jb);
diff --git a/main/fixedjitterbuf.c b/main/fixedjitterbuf.c
index 6c92329..3601e26 100644
--- a/main/fixedjitterbuf.c
+++ b/main/fixedjitterbuf.c
@@ -156,11 +156,11 @@
 	   offset */
 	offset = diff - jb->tail->ms;
 
 	/* Do we really need to resynch, or this is just a frame for dropping? */
 	if (!jb->force_resynch && (offset < jb->conf.resync_threshold && offset > -jb->conf.resync_threshold))
 		return FIXED_JB_DROP;
 
 	/* Reset the force resynch flag */
 	jb->force_resynch = 0;
 
 	/* apply the offset to the jb state */
@@ -211,7 +211,7 @@
 	/* check if the new frame is not too late */
 	if (delivery < jb->next_delivery) {
 		/* should drop the frame, but let first resynch_jb() check if this is not a jump in ts, or
-		   the force resynch flag was not set. */
+		   the force resync flag was not set. */
 		return resynch_jb(jb, data, ms, ts, now);
 	}
 
@@ -219,7 +219,7 @@
 	   However, allow more resync_threshold ms in advance */
 	if (delivery > jb->next_delivery + jb->delay + jb->conf.resync_threshold) {
 		/* should drop the frame, but let first resynch_jb() check if this is not a jump in ts, or
-		   the force resynch flag was not set. */
+		   the force resync flag was not set. */
 		return resynch_jb(jb, data, ms, ts, now);
 	}
 
@@ -234,15 +234,15 @@
 		         delivery < frame->delivery + frame->ms ||
 		         (frame->next && delivery + ms > frame->next->delivery)))
 	{
 		/* TODO: Should we check for resynch here? Be careful to do not allow threshold smaller than
 		   the size of the jb */
 
 		/* should drop the frame, but let first resynch_jb() check if this is not a jump in ts, or
-		   the force resynch flag was not set. */
+		   the force resync flag was not set. */
 		return resynch_jb(jb, data, ms, ts, now);
 	}
 
 	/* Reset the force resynch flag */
 	jb->force_resynch = 0;
 
 	/* Get a new frame */
@@ -156,11 +156,11 @@
 	offset = diff - jb->tail->ms;
 
-	/* Do we really need to resynch, or this is just a frame for dropping? */
+	/* Do we really need to resync, or this is just a frame for dropping? */
 	if (!jb->force_resynch && (offset < jb->conf.resync_threshold && offset > -jb->conf.resync_threshold))
 		return FIXED_JB_DROP;
@@ -156,11 +156,11 @@
 		return FIXED_JB_DROP;
 
-	/* Reset the force resynch flag */
+	/* Reset the force resync flag */
 	jb->force_resynch = 0;
 
@@ -234,15 +234,15 @@
 		         (frame->next && delivery + ms > frame->next->delivery)))
 	{
-		/* TODO: Should we check for resynch here? Be careful to do not allow threshold smaller than
+		/* TODO: Should we check for resync here? Be careful to do not allow threshold smaller than
 		   the size of the jb */
 
@@ -234,15 +234,15 @@
 	}
 
-	/* Reset the force resynch flag */
+	/* Reset the force resync flag */
 	jb->force_resynch = 0;
 
diff --git a/tests/test_jitterbuf.c b/tests/test_jitterbuf.c
index 76fb3c4..dd7334d 100644
--- a/tests/test_jitterbuf.c
+++ b/tests/test_jitterbuf.c
@@ -1067,7 +1067,7 @@
 
 /*!
  * \internal
  * \brief Insert frames into the jitter buffer for the resynch tests
  */
 static void test_jb_resynch_frame_insertion(struct jitterbuf *jb, enum jb_frame_type frame_type)
 {
@@ -1096,7 +1096,7 @@
 	case TEST_INIT:
 		info->name = "jitterbuffer_resynch_control";
 		info->category = "/main/jitterbuf/";
-		info->summary = "Tests sending control frames that force a resynch";
+		info->summary = "Tests sending control frames that force a resync";
 		info->description = "Control frames are sent to a jitter buffer.  After some "
 			"number of frames, the source timestamps jump, forcing a resync of "
 			"the jitter buffer.  Since the frames are control, the resync happens "
@@ -1171,7 +1171,7 @@
 	case TEST_INIT:
 		info->name = "jitterbuffer_resynch_voice";
 		info->category = "/main/jitterbuf/";
-		info->summary = "Tests sending voice frames that force a resynch";
+		info->summary = "Tests sending voice frames that force a resync";
 		info->description = "Voice frames are sent to a jitter buffer.  After some "
 			"number of frames, the source timestamps jump, forcing a resync of "
 			"the jitter buffer.  Since the frames are voice, the resync happens "
@@ -1272,7 +1272,7 @@
 	AST_TEST_REGISTER(jitterbuffer_overflow_voice);
 	AST_TEST_REGISTER(jitterbuffer_overflow_control);
 
-	/* Buffer resynch */
+	/* Buffer resync */
 	AST_TEST_REGISTER(jitterbuffer_resynch_voice);
 	AST_TEST_REGISTER(jitterbuffer_resynch_control);
 
@@ -1067,7 +1067,7 @@
 /*!
  * \internal
- * \brief Insert frames into the jitter buffer for the resynch tests
+ * \brief Insert frames into the jitter buffer for the resync tests
  */
 static void test_jb_resynch_frame_insertion(struct jitterbuf *jb, enum jb_frame_type frame_type)

-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17166
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: Iaf8f32b154246b0a5c4630481471bd8421c77ff7
Gerrit-Change-Number: 17166
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/7974566a/attachment-0001.html>


More information about the asterisk-code-review mailing list